#!/bin/bash

ANDROID_SDK=~/Library/Android/sdk

echo "***********"
echo "*  Build  *"
echo "***********"

./gradlew assembleDebug; gradlew_return_code=$?

# Check if build faild
if ((gradlew_return_code != 0)); then
echo "Grade failed with exit status $gradlew_return_code"
exit 1
fi

echo ""
echo ""
echo "********************"
echo "*  Run Unit Tests  *"
echo "********************"

./gradlew test; gradlew_return_code=$?

# Check if unit tests faild
if ((gradlew_return_code != 0)); then
echo "Grade failed with exit status $gradlew_return_code"
exit 1
fi

echo ""
echo ""
echo "****************************"
echo "*  Run Instrumental Tests  *"
echo "****************************"

$ANDROID_SDK/tools/emulator -avd Nexus_6_API_24 -wipe-data &
EMULATOR_PID=$!


# Wait for Android to finish booting
WAIT_CMD="$ANDROID_SDK/platform-tools/adb wait-for-device shell getprop init.svc.bootanim"
echo ""
echo ""

until $WAIT_CMD | grep -m 1 stopped; do
echo "Waiting for device..."
sleep 1
done

echo ""
echo ""

# Unlock the Lock Screen
$ANDROID_SDK/platform-tools/adb shell input keyevent 82

# Clear and capture logcat
$ANDROID_SDK/platform-tools/adb logcat -c
$ANDROID_SDK/platform-tools/adb logcat > build/logcat.log &
LOGCAT_PID=$!

# Run the tests
./gradlew connectedAndroidTest; gradlew_return_code=$?

# Stop the background processes
kill $LOGCAT_PID
kill $EMULATOR_PID

# Check if instrumental tests faild
if ((gradlew_return_code != 0)); then
echo "Grade failed with exit status $gradlew_return_code"
exit 1
fi


