package com.outbrain.catalog.HeroGrid;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatActivity;
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;

import com.outbrain.OBSDK.Entities.OBRecommendation;
import com.outbrain.OBSDK.Entities.OBRecommendationsResponse;
import com.outbrain.OBSDK.FetchRecommendations.OBRequest;
import com.outbrain.OBSDK.FetchRecommendations.RecommendationsListener;
import com.outbrain.OBSDK.Outbrain;
import com.outbrain.catalog.OBViewWizard.OBWidgetListener;
import com.outbrain.catalog.R;
import com.outbrain.catalog.Utils.CatalogUtils;
import com.squareup.picasso.Picasso;

import java.util.ArrayList;


public class HeroGridActivity extends AppCompatActivity implements RecommendationsListener, OBWidgetListener, SwipeRefreshLayout.OnRefreshListener {
    private ListView listView;
    private SwipeRefreshLayout swipeLayout;
    private int incrementalIndex = 0;
    private HeroGridAdapter adapter;

    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.outbrain_single_list_view_pull_to_refresh_activity);
        adapter = new HeroGridAdapter(this, this);

        listView = findViewById(R.id.outbrain_main_list_view);
        swipeLayout = findViewById(R.id.swipe_container);
        swipeLayout.setOnRefreshListener(this);
        swipeLayout.setColorSchemeResources(android.R.color.holo_blue_bright,
                android.R.color.holo_green_light,
                android.R.color.holo_orange_light,
                android.R.color.holo_red_light);

        listView.setAdapter(adapter);
    }

    @Override
    protected void onResume() {
        super.onResume();
        incrementalIndex = 0;
        executeGetRecommendationsRequest();
    }

    private void executeGetRecommendationsRequest() {
        OBRequest request = new OBRequest(getString(R.string.outbrain_sample_url), incrementalIndex++, "SDK_4");
        Outbrain.fetchRecommendations(request, this);
    }

    private boolean recommendationAlreadyInAdapter(OBRecommendation rec) {
        for (OBRecommendation rec2 : adapter.recommendations) {
            if (rec.getContent().equals(rec2.getContent())) {
                return true;
            }
        }
        return false;
    }

    @Override
    public void onOutbrainRecommendationsSuccess(final OBRecommendationsResponse recommendations) {

        for (OBRecommendation rec : recommendations.getAll()) {
            if (recommendationAlreadyInAdapter(rec) == false) {
                adapter.recommendations.add(rec);
            }
        }

        if (adapter.recommendations.size() < 6) { // we want to show the user at least 6 recommendations
            executeGetRecommendationsRequest();
            return;
        }

        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                adapter.notifyDataSetChanged();
                swipeLayout.setRefreshing(false);
            }
        });
    }

    @Override
    public void onOutbrainRecommendationsFailure(Exception ex) {
        ex.printStackTrace();
    }

    @Override
    public void onRecommendationClick(OBRecommendation recommendation) {
        openRecommendationInBrowser(recommendation);
    }

    @Override
    public void onAdChoicesClick(String url) {
        CatalogUtils.openURLInBrowser(url, this);
    }

    private void openRecommendationInBrowser(OBRecommendation obRecommendation) {
        CatalogUtils.openURLInBrowser(Outbrain.getUrl(obRecommendation), this);
    }

    @Override
    public void onRefresh() {
        new Handler().postDelayed(new Runnable() {
            @Override public void run() {
                executeGetRecommendationsRequest();
            }
        }, 5000);
    }
}

class HeroGridAdapter extends BaseAdapter {

    private final Context context;
    public ArrayList<OBRecommendation> recommendations;
    private final OBWidgetListener listener;

    public HeroGridAdapter(Context context, OBWidgetListener listener) {
        super();
        this.context = context;
        recommendations = new ArrayList<OBRecommendation>();
        this.listener = listener;
    }

    private void setGridItemWithContent(GridItemHolder item, final OBRecommendation doc) {
        item.titleTextView.setText(doc.getContent());
        item.authorTextView.setText(doc.getSourceName());
        Picasso.get().load(doc.getThumbnail().getUrl()).into(item.imageView);

        item.overlayButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                listener.onRecommendationClick(doc);
            }
        });
    }

    @Override
    public int getCount() {
        if (recommendations.size() == 0) {
            return 0;
        }
        return recommendations.size() / 2 + (recommendations.size() % 2);
    }

    @Override
    public Object getItem(int i) {
        return null;
    }

    @Override
    public long getItemId(int i) {
        return 0;
    }

    @Override
    public View getView(int i, View view, ViewGroup viewGroup) {
        GridViewHolder viewHolder;
        if (view == null) {
            view = LayoutInflater.from(context).inflate(R.layout.outbrain_grid_hero_cell, null);
            viewHolder = new GridViewHolder();

            // Left Item
            viewHolder.leftItem.titleTextView = view.findViewById(R.id.outbrain_layouts_title_text_label_left);
            viewHolder.leftItem.authorTextView = view.findViewById(R.id.outbrain_layouts_author_text_label_left);
            viewHolder.leftItem.imageView = view.findViewById(R.id.outbrain_layouts_image_view_left);
            viewHolder.leftItem.overlayButton = view.findViewById(R.id.outbrain_layouts_grid_button_left);

            // Right item
            viewHolder.rightItem.titleTextView = view.findViewById(R.id.outbrain_layouts_title_text_label_right);
            viewHolder.rightItem.authorTextView = view.findViewById(R.id.outbrain_layouts_author_text_label_right);
            viewHolder.rightItem.imageView = view.findViewById(R.id.outbrain_layouts_image_view_right);
            viewHolder.rightItem.overlayButton = view.findViewById(R.id.outbrain_layouts_grid_button_right);

            view.setTag(viewHolder);
        } else {
            viewHolder = (GridViewHolder) view.getTag();
        }

        //left
        final OBRecommendation docLeft = recommendations.get(2 * i);
        final OBRecommendation docRight = (recommendations.size() >= 2*(i+1)) ? recommendations.get(2*i + 1) : null;

        setGridItemWithContent(viewHolder.leftItem, docLeft);
        if (docRight != null) {
            setGridItemWithContent(viewHolder.rightItem, docRight);
        }


        return view;
    }

    static class GridItemHolder {
        TextView titleTextView;
        TextView authorTextView;
        ImageView imageView;
        Button overlayButton;
    }

    static class GridViewHolder {
        GridItemHolder leftItem;
        GridItemHolder rightItem;

        public GridViewHolder() {
            this.leftItem = new GridItemHolder();
            this.rightItem = new GridItemHolder();
        }
    }
}