package com.outbrain.catalog.HeroGrid;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.RelativeLayout;
import android.widget.TextView;


import androidx.appcompat.app.AppCompatActivity;
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;

import com.outbrain.OBSDK.Entities.OBRecommendation;
import com.outbrain.OBSDK.Entities.OBRecommendationsResponse;
import com.outbrain.OBSDK.FetchRecommendations.OBRequest;
import com.outbrain.OBSDK.FetchRecommendations.RecommendationsListener;
import com.outbrain.OBSDK.Outbrain;
import com.outbrain.catalog.OBViewWizard.OBWidgetListener;
import com.outbrain.catalog.R;
import com.outbrain.catalog.Utils.CatalogUtils;
import com.squareup.picasso.Picasso;

import java.util.ArrayList;


public class HeroListActivity extends AppCompatActivity implements RecommendationsListener, OBWidgetListener, SwipeRefreshLayout.OnRefreshListener {
    private ListView listView;
    private SwipeRefreshLayout swipeLayout;
    private int incrementalIndex = 0;
    private HeroListAdapter adapter;

    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.outbrain_single_list_view_pull_to_refresh_activity);
        adapter = new HeroListAdapter(this, this);

        listView = findViewById(R.id.outbrain_main_list_view);
        swipeLayout = findViewById(R.id.swipe_container);
        swipeLayout.setOnRefreshListener(this);
        swipeLayout.setColorSchemeResources(android.R.color.holo_blue_bright,
                android.R.color.holo_green_light,
                android.R.color.holo_orange_light,
                android.R.color.holo_red_light);

        listView.setAdapter(adapter);
        executeGetRecommendationsRequest();
    }

    private void executeGetRecommendationsRequest() {
        OBRequest request = new OBRequest(getString(R.string.outbrain_sample_url), incrementalIndex++, "SDK_4");
        Outbrain.fetchRecommendations(request, this);
    }

    @Override
    public void onOutbrainRecommendationsSuccess(final OBRecommendationsResponse recommendations) {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                adapter.recommendations.addAll(recommendations.getAll());
                adapter.notifyDataSetChanged();
                swipeLayout.setRefreshing(false);
            }
        });
    }

    @Override
    public void onOutbrainRecommendationsFailure(Exception ex) {
        ex.printStackTrace();
    }

    @Override
    public void onRecommendationClick(OBRecommendation recommendation) {
        openRecommendationInBrowser(recommendation);
    }

    @Override
    public void onAdChoicesClick(String url) {
        CatalogUtils.openURLInBrowser(url, this);
    }

    private void openRecommendationInBrowser(OBRecommendation obRecommendation) {
        CatalogUtils.openURLInBrowser(Outbrain.getUrl(obRecommendation), this);
    }

    @Override
    public void onRefresh() {
        new Handler().postDelayed(new Runnable() {
            @Override public void run() {
                executeGetRecommendationsRequest();
            }
        }, 5000);
    }
}

class HeroListAdapter extends BaseAdapter {

    private final Context context;
    public ArrayList<OBRecommendation> recommendations;
    private final OBWidgetListener listener;

    public HeroListAdapter(Context context, OBWidgetListener listener) {
        super();
        this.context = context;
        recommendations = new ArrayList<OBRecommendation>();
        this.listener = listener;
    }

    @Override
    public int getCount() {
        if (recommendations.size() == 0) {
            return 0;
        }
        return recommendations.size();
    }

    @Override
    public Object getItem(int i) {
        return null;
    }

    @Override
    public long getItemId(int i) {
        return 0;
    }

    @Override
    public View getView(int i, View view, ViewGroup viewGroup) {
        if (getItemViewType(i) == 0) {
            HeaderViewHolder viewHolder;
            if (view == null) {
                view = LayoutInflater.from(context).inflate(R.layout.outbrain_grid_hero_header, null);
                viewHolder = new HeaderViewHolder();
                viewHolder.titleTextView = view.findViewById(R.id.outbrain_layouts_title_text_label);
                viewHolder.authorTextView = view.findViewById(R.id.outbrain_layouts_author_text_label);
                viewHolder.disclosureImageView = view.findViewById(R.id.outbrain_rec_disclosure_image_view);
                viewHolder.imageView = view.findViewById(R.id.outbrain_rec_image_view);
                viewHolder.mainLayout = view.findViewById(R.id.outbrain_layouts_main);
                view.setTag(viewHolder);
            } else {
                viewHolder = (HeaderViewHolder) view.getTag();
            }

            final OBRecommendation doc = recommendations.get(i);
            viewHolder.titleTextView.setText(doc.getContent());
            viewHolder.authorTextView.setText(doc.getSourceName());
            Picasso.get().load(doc.getThumbnail().getUrl()).into(viewHolder.imageView);

            viewHolder.mainLayout.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    listener.onRecommendationClick(doc);
                }
            });

            if (doc.isPaid() && doc.shouldDisplayDisclosureIcon()) {
                // Set the RTB disclosure icon image and click handler
                viewHolder.disclosureImageView.setVisibility(View.VISIBLE);
                Picasso.get().load(doc.getDisclosure().getIconUrl()).into(viewHolder.disclosureImageView);
                viewHolder.disclosureImageView.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        CatalogUtils.openURLInBrowser(doc.getDisclosure().getClickUrl(), context);
                    }
                });
            }
            else {
                viewHolder.disclosureImageView.setVisibility(View.GONE);
            }
        }

        return view;
    }

    static class HeaderViewHolder {
        TextView titleTextView;
        TextView authorTextView;
        ImageView imageView;
        ImageView disclosureImageView;
        RelativeLayout mainLayout;
    }
}