package com.outbrain.catalog.HeroGrid;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatActivity;
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;

import com.outbrain.OBSDK.Entities.OBRecommendation;
import com.outbrain.OBSDK.Entities.OBRecommendationsResponse;
import com.outbrain.OBSDK.FetchRecommendations.OBRequest;
import com.outbrain.OBSDK.FetchRecommendations.RecommendationsListener;
import com.outbrain.OBSDK.Outbrain;
import com.outbrain.catalog.OBViewWizard.OBWidgetListener;
import com.outbrain.catalog.R;
import com.outbrain.catalog.Utils.CatalogUtils;
import com.squareup.picasso.Picasso;

import java.util.ArrayList;


public class MixedInterstitialActivity extends AppCompatActivity implements RecommendationsListener, OBWidgetListener, SwipeRefreshLayout.OnRefreshListener {
    private int incrementalIndex = 0;
    private HeroGridWithHeaderAdapter adapter;
    private ListView listView;
    private SwipeRefreshLayout swipeLayout;


    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.outbrain_full_experience_grid_activity);
        listView = findViewById(R.id.outbrain_main_list_view);
        adapter = new HeroGridWithHeaderAdapter(this, this);

        swipeLayout = findViewById(R.id.swipe_container);
        swipeLayout.setOnRefreshListener(this);
        swipeLayout.setColorSchemeResources(android.R.color.holo_blue_bright,
                android.R.color.holo_green_light,
                android.R.color.holo_orange_light,
                android.R.color.holo_red_light);

        listView.setAdapter(adapter);

        executeGetRecommendationsRequest();
    }

    private void executeGetRecommendationsRequest() {
        OBRequest request = new OBRequest(getString(R.string.outbrain_sample_url), incrementalIndex++, "SDK_4");
        Outbrain.fetchRecommendations(request, this);
    }

    @Override
    public void onOutbrainRecommendationsSuccess(final OBRecommendationsResponse recommendations) {
        adapter.recommendations.addAll(recommendations.getAll());
        adapter.notifyDataSetChanged();
        swipeLayout.setRefreshing(false);
    }

    @Override
    public void onOutbrainRecommendationsFailure(Exception ex) {
        ex.printStackTrace();
    }

    @Override
    public void onRecommendationClick(OBRecommendation recommendation) {
        openRecommendationInBrowser(recommendation);
    }

    @Override
    public void onAdChoicesClick(String url) {
        CatalogUtils.openURLInBrowser(url, this);
    }

    private void openRecommendationInBrowser(OBRecommendation obRecommendation) {
        CatalogUtils.openURLInBrowser(Outbrain.getUrl(obRecommendation), this);
    }

    @Override
    public void onRefresh() {
        new Handler().postDelayed(new Runnable() {
            @Override public void run() {
                executeGetRecommendationsRequest();
            }
        }, 5000);
    }
}

class HeroGridWithHeaderAdapter extends BaseAdapter {

    private final Context context;
    public ArrayList<OBRecommendation> recommendations;
    private final OBWidgetListener listener;

    private final int VIEW_TYPE_HEADER = 11;
    private final int VIEW_TYPE_TWO_RECS = 22;


    public HeroGridWithHeaderAdapter(Context context, OBWidgetListener listener) {
        super();
        this.context = context;
        recommendations = new ArrayList<OBRecommendation>();
        this.listener = listener;
    }

    @Override
    public int getCount() {
        if (recommendations.size() == 0) {
            return 0;
        }
        return recommendations.size() / 2 + (recommendations.size() % 2);
    }

    @Override
    public Object getItem(int i) {
        return null;
    }

    @Override
    public long getItemId(int i) {
        return 0;
    }

    @Override
    public int getItemViewType(int position) {
        return (position == 0) ? VIEW_TYPE_HEADER : VIEW_TYPE_TWO_RECS;
    }

    @Override
    public int getViewTypeCount() {
        return 2;
    }

    @Override
    public View getView(int i, View view, ViewGroup viewGroup) {
        if (getItemViewType(i) == VIEW_TYPE_HEADER) {
            return createHeaderViewContainer(i, view);
        } else {
            // VIEW_TYPE_TWO_RECS
            GridViewHolder viewHolder;
            if (view == null) {
                view = LayoutInflater.from(context).inflate(R.layout.outbrain_grid_hero_cell, null);
                viewHolder = new GridViewHolder();
                viewHolder.titleTextViewLeft = view.findViewById(R.id.outbrain_layouts_title_text_label_left);
                viewHolder.authorTextViewLeft = view.findViewById(R.id.outbrain_layouts_author_text_label_left);
                viewHolder.imageViewLeft = view.findViewById(R.id.outbrain_layouts_image_view_left);
                viewHolder.disclosureImageViewLeft = view.findViewById(R.id.outbrain_rec_disclosure_image_view_left);
                viewHolder.overlayButtonLeft = view.findViewById(R.id.outbrain_layouts_grid_button_left);
                viewHolder.titleTextViewRight = view.findViewById(R.id.outbrain_layouts_title_text_label_right);
                viewHolder.authorTextViewRight = view.findViewById(R.id.outbrain_layouts_author_text_label_right);
                viewHolder.imageViewRight = view.findViewById(R.id.outbrain_layouts_image_view_right);
                viewHolder.disclosureImageViewRight = view.findViewById(R.id.outbrain_rec_disclosure_image_view_right);
                viewHolder.overlayButtonRight = view.findViewById(R.id.outbrain_layouts_grid_button_right);
                view.setTag(viewHolder);
            } else {
                viewHolder = (GridViewHolder) view.getTag();
            }

            //left
            final OBRecommendation doc = (i == 0 ? recommendations.get(0) : recommendations.get(2 * i - 1));
            viewHolder.titleTextViewLeft.setText(doc.getContent());
            viewHolder.authorTextViewLeft.setText(doc.getSourceName());
            Picasso.get().load(doc.getThumbnail().getUrl()).into(viewHolder.imageViewLeft);

            setupRecDisclosureIcon(view.getContext(), viewHolder.disclosureImageViewLeft, doc);

            viewHolder.overlayButtonLeft.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    listener.onRecommendationClick(doc);
                }
            });
            if (2 * i < recommendations.size()) {

                //right
                final OBRecommendation docRight = recommendations.get(2 * i);

                viewHolder.titleTextViewRight.setText(docRight.getContent());
                viewHolder.authorTextViewRight.setText(docRight.getSourceName());
                Picasso.get().load(docRight.getThumbnail().getUrl()).into(viewHolder.imageViewRight);
                setupRecDisclosureIcon(view.getContext(), viewHolder.disclosureImageViewRight, docRight);
                viewHolder.overlayButtonRight.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View view) {
                        listener.onRecommendationClick(docRight);
                    }
                });
            }
        }

        return view;
    }

    private View createHeaderViewContainer(int i, View view) {
        HeaderViewHolder viewHolder;
        if (view == null) {
            view = LayoutInflater.from(context).inflate(R.layout.outbrain_grid_hero_header, null);
            viewHolder = new HeaderViewHolder();
            viewHolder.titleTextView = view.findViewById(R.id.outbrain_layouts_title_text_label);
            viewHolder.authorTextView = view.findViewById(R.id.outbrain_layouts_author_text_label);
            viewHolder.imageView = view.findViewById(R.id.outbrain_rec_image_view);
            viewHolder.disclosureImageView = view.findViewById(R.id.outbrain_rec_disclosure_image_view);
            viewHolder.mainLayout = view.findViewById(R.id.outbrain_layouts_main);
            view.setTag(viewHolder);
        } else {
            viewHolder = (HeaderViewHolder) view.getTag();
        }

        final OBRecommendation rec = recommendations.get(i);
        viewHolder.titleTextView.setText(rec.getContent());
        viewHolder.authorTextView.setText(rec.getSourceName());
        Picasso.get().load(rec.getThumbnail().getUrl()).into(viewHolder.imageView);

        setupRecDisclosureIcon(view.getContext(), viewHolder.disclosureImageView, rec);
        viewHolder.mainLayout.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                listener.onRecommendationClick(rec);
            }
        });

        return view;
    }

    private void setupRecDisclosureIcon(final Context ctx, ImageView disclosureImageView, final OBRecommendation rec) {
        if (rec.isPaid() && rec.shouldDisplayDisclosureIcon()) {
            // Set the RTB disclosure icon image and click handler
            disclosureImageView.setVisibility(View.VISIBLE);
            Picasso.get().load(rec.getDisclosure().getIconUrl()).into(disclosureImageView);
            disclosureImageView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    CatalogUtils.openURLInBrowser(rec.getDisclosure().getClickUrl(), ctx);
                }
            });
        }
        else {
            disclosureImageView.setVisibility(View.GONE);
        }
    }

    static class HeaderViewHolder {
        TextView titleTextView;
        TextView authorTextView;
        ImageView imageView;
        ImageView disclosureImageView;
        RelativeLayout mainLayout;
    }

    static class GridViewHolder {
        TextView titleTextViewLeft;
        TextView authorTextViewLeft;
        ImageView imageViewLeft;
        ImageView disclosureImageViewLeft;
        Button overlayButtonLeft;
        TextView titleTextViewRight;
        TextView authorTextViewRight;
        ImageView imageViewRight;
        ImageView disclosureImageViewRight;
        Button overlayButtonRight;
    }
}

