package com.outbrain.catalog.ListLayouts;

import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ImageView;
import android.widget.ListView;

import androidx.appcompat.app.AppCompatActivity;

import com.outbrain.OBSDK.Entities.OBRecommendation;
import com.outbrain.OBSDK.Entities.OBRecommendationsResponse;
import com.outbrain.OBSDK.FetchRecommendations.OBPlatformRequest;
import com.outbrain.OBSDK.FetchRecommendations.OBRequest;
import com.outbrain.OBSDK.FetchRecommendations.RecommendationsListener;
import com.outbrain.OBSDK.Outbrain;
import com.outbrain.OBSDK.Registration.RegistrationService;
import com.outbrain.catalog.R;
import com.outbrain.catalog.Utils.CatalogUtils;


public class ClassicWithImageActivity extends AppCompatActivity implements RecommendationsListener {
    ListView listView;

    private final static String OUTBRAIN_SAMPLE_WIDGET_ID = "SDK_1";
    private final static String OUTBRAIN_SAMPLE_WIDGET_URL = "http://mobile-demo.outbrain.com/2013/12/15/test-page-2";
    private final static String OUTBRAIN_SAMPLE_BUNDLE_URL = "https://play.google.com/store/apps/details?id=com.outbrain";
    private final static String OUTBRAIN_SAMPLE_PORTAL_URL = "https://lp.outbrain.com/increase-sales-native-ads/";

    private final boolean TEST_PLATFORMS = true;

    public void onCreate(Bundle savedBundle) {
        super.onCreate(savedBundle);
        setContentView(R.layout.outbrain_single_list_view_activity);

        listView = findViewById(R.id.outbrain_main_list_view);
        listView.setDivider(null);
        listView.setDividerHeight(0);
        View headerView = getLayoutInflater().inflate(R.layout.outbrain_classic_recommendation_list_header, null);
        ImageView whatIsWrapper = headerView.findViewById(R.id.recommended_by_image);
        whatIsWrapper.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                launchWhatIs();
            }
        });

        listView.addHeaderView(headerView);

        fetchForRecommendations();
    }

    private void launchWhatIs() {
        String aboutOutbrainUrl = Outbrain.getOutbrainAboutURL(this);
        CatalogUtils.openURLInBrowser(aboutOutbrainUrl, this);
    }

    private void fetchForRecommendations() {
        if (TEST_PLATFORMS) {
            RegistrationService.WAS_INITIALIZED = false;
            Outbrain.register(this, "DEMOP1MN24J3E1MGLQ92067LH");
            OBPlatformRequest platformRequest = new OBPlatformRequest(OUTBRAIN_SAMPLE_WIDGET_ID, null, OUTBRAIN_SAMPLE_PORTAL_URL, "en");
            Outbrain.fetchRecommendations(platformRequest, this);
        }
        else {
            OBRequest request = new OBRequest();
            request.setWidgetId(OUTBRAIN_SAMPLE_WIDGET_ID);
            request.setUrl(OUTBRAIN_SAMPLE_WIDGET_URL);
            Outbrain.fetchRecommendations(request, this);
        }
    }

    @Override
    public void onOutbrainRecommendationsSuccess(final OBRecommendationsResponse recommendationsResponse) {
        assignAdapter(recommendationsResponse);
        OBRequest obRequest = recommendationsResponse.getObRequest();
    }

    @Override
    public void onOutbrainRecommendationsFailure(Exception ex) {
        ex.printStackTrace();
    }

    private void assignAdapter(final OBRecommendationsResponse recommendations) {
        OutbrainSingleItemLayoutAdapter adapter = new OutbrainSingleItemLayoutAdapter(this, R.layout.classic_with_image, recommendations.getAll());
        listView.setAdapter(adapter);
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                try{
                    openRecommendationInBrowser(recommendations.get(i-1));
                } catch (Exception e){}
            }
        });
    }

    private void openRecommendationInBrowser(OBRecommendation obRecommendation) {
        CatalogUtils.openURLInBrowser(Outbrain.getUrl(obRecommendation), this);
    }
}

