#!/bin/bash

if [ $# -eq 0 ]; then
echo "version parameter is missing"
exit 1
fi

NEW_SDK_VER=$1

echo ""
echo "*************************************"
echo "* Running script - update Custom UI *"
echo "*************************************"

echo ""
echo "*****************************"
echo " Creating OBSDK-CustomUI dir"
echo "*****************************"
rm -fr OBSDK-CustomUI
mkdir OBSDK-CustomUI
mkdir OBSDK-CustomUI/SFSingleCells/
mkdir OBSDK-CustomUI/SFHorizontalItemsCells/
mkdir OBSDK-CustomUI/SFHeaderCells/
mkdir OBSDK-CustomUI/SFReadMoreModuleCells/

echo ""
echo "****************************************"
echo " Copy Custom UI files to OBSDK-CustomUI"
echo "****************************************"

LAYOUTS_PATH="obsdk/src/main/res/layout"

cp ${LAYOUTS_PATH}/outbrain_sfeed_header.xml OBSDK-CustomUI/SFHeaderCells/outbrain_sfeed_header_custom.xml
cp ${LAYOUTS_PATH}/outbrain_sfeed_horizontal_item.xml OBSDK-CustomUI/SFHorizontalItemsCells/outbrain_sfeed_horizontal_item_custom.xml
cp ${LAYOUTS_PATH}/outbrain_sfeed_single_rec.xml OBSDK-CustomUI/SFHorizontalItemsCells/outbrain_sfeed_single_rec_in_line_custom.xml
cp ${LAYOUTS_PATH}/outbrain_sfeed_single_item.xml OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_single_item_custom.xml
cp ${LAYOUTS_PATH}/outbrain_sfeed_single_item.xml OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_single_item_with_title.xml
cp ${LAYOUTS_PATH}/outbrain_sfeed_strip_thumnbnail.xml OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_strip_thumnbnail_custom.xml
cp ${LAYOUTS_PATH}/outbrain_sfeed_strip_thumnbnail.xml OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_strip_thumnbnail_with_title.xml
cp ${LAYOUTS_PATH}/outbrain_sfeed_read_more_item.xml OBSDK-CustomUI/SFReadMoreModuleCells/outbrain_sfeed_read_more_item_custom.xml

cp ${LAYOUTS_PATH}/outbrain_sfeed_single_item_header.xml OBSDK-CustomUI/outbrain_sfeed_single_item_header_custom.xml
sed -i '/xml version/d' OBSDK-CustomUI/outbrain_sfeed_single_item_header_custom.xml

echo ""
echo "***************************************************"
echo " Remove included title from layouts without title "
echo "***************************************************"

sed -i '/outbrain_sfeed_single_item_header/d' OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_single_item_custom.xml
sed -i '/outbrain_sfeed_single_item_header/d' OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_strip_thumnbnail_custom.xml

echo ""
echo "*******************************************************************"
echo " Replace included title with title xml from layouts without title "
echo "*******************************************************************"

sed -e '/outbrain_sfeed_single_item_header/r OBSDK-CustomUI/outbrain_sfeed_single_item_header_custom.xml' -e '/outbrain_sfeed_single_item_header/d' OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_single_item_with_title.xml > OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_single_item_with_title_custom.xml

sed -e '/outbrain_sfeed_single_item_header/r OBSDK-CustomUI/outbrain_sfeed_single_item_header_custom.xml' -e '/outbrain_sfeed_single_item_header/d' OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_strip_thumnbnail_with_title.xml > OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_strip_thumnbnail_with_title_custom.xml

rm OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_single_item_with_title.xml
rm OBSDK-CustomUI/SFSingleCells/outbrain_sfeed_strip_thumnbnail_with_title.xml
rm OBSDK-CustomUI/outbrain_sfeed_single_item_header_custom.xml

echo ""
echo "*************************************************************"
echo " zip Custom UI files to Custom-UI-Android-SDK-Smartfeed.zip"
echo "*************************************************************"

cd OBSDK-CustomUI/
zip -r Custom-UI-Android-SDK-Smartfeed.zip .
rm -fr SFSingleCells/
rm -fr SFHorizontalItemsCells/
rm -fr SFHeaderCells/
ls
cd ..

echo ""
echo "*******************"
echo " Upload to GCP Storage"
echo "*******************"
PACKAGE_ANDROID_CUSTOM_UI="Android-Custom-UI-SDK-Smartfeed"

cd ../scripts
./upload_to_gcp_storage.sh ../catalog-app/OBSDK-CustomUI/Custom-UI-Android-SDK-Smartfeed.zip Custom-UI-Android-SDK-Smartfeed.zip $NEW_SDK_VER


echo ""
echo ""
echo "***************************"
echo "* Finish update Custom UI *"
echo "***************************"
